@@ -673,6 +673,16 @@ class Storage(base.Storage):
         bucket = self.getBucket(bucketOrBucketName)
         return bucket.object_exists(key)
 
+    def presignedGetObject(self, key, expires=3600, bucketOrBucketName=None, slash_safe=False):
+        bucket = self.getBucket(bucketOrBucketName)
+        url = bucket.sign_url('GET', key, expires, slash_safe=slash_safe)
+        return url
+
+    def presignedPutObject(self, key, expires=3600, bucketOrBucketName=None, slash_safe=False):
+        bucket = self.getBucket(bucketOrBucketName)
+        url = bucket.sign_url('PUT', key, expires, slash_safe=slash_safe)
+        return url
+
     def getStorageMd5(self, key, bucketOrBucketName=None):
         bucket = self.getBucket(bucketOrBucketName)
         try:
